@@ -1,4 +1,4 @@
-// Copyright (C) 2001,2002 Federico Montesino Pouzols <fedemp@altern.org>.
+// Copyright (C) 2001,2002,2004 Federico Montesino Pouzols <fedemp@altern.org>.
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -14,29 +14,26 @@
 // along with this program; if not, write to the Free Software 
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
-// As a special exception to the GNU General Public License, permission is 
-// granted for additional uses of the text contained in its release 
-// of ccRTP.
-// 
-// The exception is that, if you link the ccRTP library with other
-// files to produce an executable, this does not by itself cause the
-// resulting executable to be covered by the GNU General Public License.
-// Your use of that executable is in no way restricted on account of
-// linking the ccRTP library code into it.
-// 
-// This exception does not however invalidate any other reasons why
-// the executable file might be covered by the GNU General Public License.
-// 
-// This exception applies only to the code released under the 
-// name ccRTP.  If you copy code from other releases into a copy of
+// As a special exception, you may use this file as part of a free software
+// library without restriction.  Specifically, if other files instantiate
+// templates or use macros or inline functions from this file, or you compile
+// this file and link it with other files to produce an executable, this
+// file does not by itself cause the resulting executable to be covered by
+// the GNU General Public License.  This exception does not however    
+// invalidate any other reasons why the executable file might be covered by
+// the GNU General Public License.    
+//
+// This exception applies only to the code released under the name GNU
+// ccRTP.  If you copy code from other releases into a copy of GNU
 // ccRTP, as the General Public License permits, the exception does
 // not apply to the code that you add in this way.  To avoid misleading
 // anyone as to the status of such modified files, you must delete
 // this exception notice from them.
-// 
-// If you write modifications of your own for ccRTP, it is your choice
+//
+// If you write modifications of your own for GNU ccRTP, it is your choice
 // whether to permit this exception to apply to your modifications.
-// If you do not wish that, delete this exception notice.  
+// If you do not wish that, delete this exception notice.
+//
 
 /** 
  * @file cqueue.h 
@@ -80,8 +77,8 @@ namespace ost {
  *
  * @author Federico Montesino Pouzols <fedemp@altern.org>
  **/
-class CCXX_CLASS_EXPORT QueueRTCPManager : public RTPDataQueue,
-					   protected RTCPCompoundHandler
+class __EXPORT QueueRTCPManager : public RTPDataQueue, 
+	protected RTCPCompoundHandler
 {
 public:
 	/**
@@ -265,6 +262,8 @@ protected:
 	 * @param source Synchronization source of SDES chunk.
 	 * @param chunk SDES chunk structure.
 	 * @param len Length of chunk, in octets.
+	 *
+	 * @return whether there was a CNAME.
 	 **/
 	virtual bool
 	onGotSDESChunk(SyncSource& source, SDESChunk& chunk, size_t len);
@@ -319,7 +318,7 @@ protected:
 	 * long as at least one RTP or RTCP packet has been sent
 	 * before. If the number of members in the session is more
 	 * than 50, the algorithm described in section 6.3.7 of
-	 * draft-ietf-avt-rtp-new is applied in order to avoid a flood
+	 * RFC 3550 is applied in order to avoid a flood
 	 * of BYE messages.
 	 *
 	 * @param reason reason to specify in the BYE packet.
@@ -365,8 +364,9 @@ private:
 	 * in the session.
 	 *
 	 * @note This currently follows the rules in section 6 of
-	 *       draft-ietf-avt-rtp-new-10
-	 * @todo make it more flexible as recommended in the draft
+	 *       RFC 3550
+	 * @todo make it more flexible as recommended in the draft. For now,
+	 * we have setMinRTCPInterval.
 	 *
 	 * @return interval for sending RTCP compound packets
 	 **/
@@ -485,7 +485,8 @@ private:
 	 *
 	 * @note MUST be perform at least every RTCP transmission
 	 *       interval
-	 * @todo implement it 
+	 * @todo implement it. It may be dangerous and anyway should
+	 * be optional.
 	 **/
 	void 
 	expireSSRCs();
@@ -662,7 +663,7 @@ protected:
 /** @}*/ // cqueue
 
 #ifdef  CCXX_NAMESPACES
-};
+}
 #endif
 
 #endif  //CCXX_RTP_CQUEUE_H_
